#
# Cookbook Name:: railsapp
# Recipe:: default
#

require 'chef-deploy'

include_recipe 'git'
include_recipe 'apache2'
include_recipe 'apache2::mod_rewrite'
include_recipe 'apache2::mod_rails'

gem_package 'rails'
package 'libsqlite3-ruby1.8'

appname = "railsapp"

["config", "log", "pids", "sqlite"].each do |d|
  directory "/srv/#{appname}/shared/#{d}" do
    owner "edd"
    group "edd"
    mode "0775"
    recursive true
  end
end

remote_file "/srv/#{appname}/shared/config/database.yml" do
  source "database.yml"
  owner "edd"
  group "edd"
  mode "0444"
end

file "/srv/#{appname}/shared/sqlite/production.sqlite3" do
  owner "edd"
  group "edd"
  mode "0664"
end

deploy "/srv/#{appname}" do
  repo "git://jauntyserv.local/git/#{appname}.git"
  branch "HEAD"
  user "edd"
  enable_submodules false
  migrate true
  migration_command "rake db:migrate"
  environment "production"
  shallow_clone true
  revision '3f618885c010074b73be012b000e0b1acf8dbae9'
  action :deploy # or :rollback
  restart_command "" # weird bug
end

web_app "#{appname}" do
  template "rails_app.conf.erb"
  server_name "#{node[:fqdn]}"
  docroot "/srv/#{appname}/current/public"
end

# finally, disable the default apache2 server
link "#{node[:apache][:dir]}/sites-enabled/000-default" do
  action :delete
  notifies :reload, resources(:service => "apache2"), :delayed
end
